pub struct TuiPagesBuilder<V, A, S, O = (), M = (), Pages = (), Handler = ()> { /* private fields */ }Implementations
Sourceimpl<V, A, S, O, M> TuiPagesBuilder<V, A, S, O, M, (), ()>
impl<V, A, S, O, M> TuiPagesBuilder<V, A, S, O, M, (), ()>
Sourceimpl<V, A, S, O, M, Pages, Handler> TuiPagesBuilder<V, A, S, O, M, Pages, Handler>
impl<V, A, S, O, M, Pages, Handler> TuiPagesBuilder<V, A, S, O, M, Pages, Handler>
pub fn fallback_view(self, fallback_view: V) -> Self
pub fn input_timeout_ms(self, timeout_ms: u64) -> Self
pub fn command_timeout_ms(self, timeout_ms: u64) -> Self
pub fn pages<NextPages>( self, pages: NextPages, ) -> TuiPagesBuilder<V, A, S, O, M, NextPages, Handler>
Sourcepub fn page_fn(
self,
page_fn: PageFn<V, S, O>,
) -> TuiPagesBuilder<V, A, S, O, M, PageFn<V, S, O>, Handler>
pub fn page_fn( self, page_fn: PageFn<V, S, O>, ) -> TuiPagesBuilder<V, A, S, O, M, PageFn<V, S, O>, Handler>
Set the page provider to a plain fn, coercing it to PageFn at the
call site so the application never writes page_spec as PageFn<…>.
.pages(f) keeps the fn item type, which a type App = TuiPages<…>
alias cannot name; this method pins the PageFn pointer type the
alias uses, so .page_fn(page_spec) just works:
ⓘ
TuiPages::builder(View::Home).page_fn(page_spec).handler(Handler).build()pub fn handler<NextHandler>( self, handler: NextHandler, ) -> TuiPagesBuilder<V, A, S, O, M, Pages, NextHandler>
Sourcepub fn focus_wrap(self, wrap: FocusWrap) -> Self
pub fn focus_wrap(self, wrap: FocusWrap) -> Self
Set how focus navigation behaves at the ends of a list — clamp (default) or wrap-around. Applies to page focus and modal items.
pub fn keymap( self, mode: impl Into<ModeId>, configure: impl FnOnce(&mut KeyMap<A>), ) -> Self
pub fn bind(self, mode: impl Into<ModeId>, binding: &str, action: A) -> Self
pub fn command<I, Alias>( self, action_name: impl Into<String>, aliases: I, action: A, ) -> Self
pub fn build(self) -> TuiPages<V, A, S, Pages, Handler, O, M>